@@ -24,12 +24,11 @@
 #include <QQmlEngine>
 #include <QQuickItem>
 #include <QQuickWindow>
-#include <QStandardItemModel>
 
 #include <KLocalizedString>
 
-#include <kauthaction.h>
-#include <kauthexecutejob.h>
+#include <KAuth/Action>
+#include <KAuth/ExecuteJob>
 
 #include <KNewStuff3/KNSCore/EntryInternal>
 
